==> foundation-ui-components-1.2.0.tgz: package/src/common/auth-dropdown/NsAuthDropdown.tsx <==
import { useCallback, useRef, useState } from 'react';

import { NsIcon } from '../icon';
import {
    AuthDropdownContainer,
    AuthHead,
    Button,
    AuthDropdown,
    Triangle,
    SignInButton,
    SignUpLinkContainer,
    SignUpLink,
} from './NsAuthDropdown.styled';
import { NsAuthDropdownProps } from './types.d';
import { useOnClickOutside } from '../hooks/useOnClickOutside';

const NsAuthDropdown = ({
    signInRedirectLink,
    signUpRedirectLink,
    signInBtnText,
    signUpLinkText,
    signUpLinkPrefixText,
    titleText,
    closeOnMouseLeave = false,
    darkModeEnabled = true,
}: NsAuthDropdownProps) => {
    const [isOpen, setIsOpen] = useState(false);
    const dropdowneRef = useRef<HTMLDivElement | null>(null);

    const handleToggle = () => {
        setIsOpen(!isOpen);
    };

    useOnClickOutside(dropdowneRef, handleToggle);

    const closeDropdown = useCallback(() => {
        if (closeOnMouseLeave) {
            setIsOpen(false);
        }
    }, [closeOnMouseLeave]);

    return (
        <AuthDropdownContainer ref={dropdowneRef}>
            <AuthHead data-testid="auth-head" onClick={handleToggle} darkModeEnabled={darkModeEnabled}>
                <Button>{titleText}</Button>
                <NsIcon testId="chevron-icon" name={isOpen ? 'arrowUp' : 'arrowDown'} color="primary" />
                {isOpen ? (
                    <div onMouseLeave={closeDropdown} className="auth-wrapper">
                        <Triangle />
                        <AuthDropdown>
                            <SignInButton href={signInRedirectLink} data-testid="sign-in-btn">
                                {signInBtnText}
                            </SignInButton>
                            <SignUpLinkContainer>
                                {signUpLinkPrefixText}{' '}
                                <SignUpLink data-testid="signup-link" href={signUpRedirectLink}>
                                    {signUpLinkText}
                                </SignUpLink>
                            </SignUpLinkContainer>
                        </AuthDropdown>
                    </div>
                ) : null}
            </AuthHead>
        </AuthDropdownContainer>
    );
};

export default NsAuthDropdown;

==> foundation-ui-components-1.3.0.tgz: package/src/common/auth-dropdown/NsAuthDropdown.tsx <==
import { useCallback, useRef, useState } from 'react';

import { NsIcon } from '../icon';
import {
    AuthDropdownContainer,
    AuthHead,
    Button,
    AuthDropdown,
    Triangle,
    SignInButton,
    SignUpLinkContainer,
    SignUpLink,
} from './NsAuthDropdown.styled';
import { NsAuthDropdownProps } from './types.d';
import { useOnClickOutside } from '../hooks/useOnClickOutside';

const NsAuthDropdown = ({
    signInRedirectLink,
    signUpRedirectLink,
    signInBtnText,
    signUpLinkText,
    signUpLinkPrefixText,
    titleText,
    closeOnMouseLeave = false,
    darkModeEnabled = true,
}: NsAuthDropdownProps) => {
    const [isOpen, setIsOpen] = useState(false);
    const dropdowneRef = useRef<HTMLDivElement | null>(null);

    const handleToggle = useCallback(() => {
        setIsOpen(!isOpen);
    }, [isOpen]);

    const handleClose = () => {
        setIsOpen(false);
    };

    useOnClickOutside(dropdowneRef, handleClose);

    const handleOnMouseLeave = useCallback(() => {
        if (closeOnMouseLeave) {
            handleClose();
        }
    }, [closeOnMouseLeave]);

    return (
        <AuthDropdownContainer ref={dropdowneRef}>
            <AuthHead data-testid="auth-head" onClick={handleToggle} darkModeEnabled={darkModeEnabled}>
                <Button>{titleText}</Button>
                <NsIcon testId="chevron-icon" name={isOpen ? 'arrowUp' : 'arrowDown'} color="primary" />
                {isOpen ? (
                    <div onMouseLeave={handleOnMouseLeave} className="auth-wrapper">
                        <Triangle />
                        <AuthDropdown>
                            <SignInButton href={signInRedirectLink} data-testid="sign-in-btn">
                                {signInBtnText}
                            </SignInButton>
                            <SignUpLinkContainer>
                                {signUpLinkPrefixText}{' '}
                                <SignUpLink data-testid="signup-link" href={signUpRedirectLink}>
                                    {signUpLinkText}
                                </SignUpLink>
                            </SignUpLinkContainer>
                        </AuthDropdown>
                    </div>
                ) : null}
            </AuthHead>
        </AuthDropdownContainer>
    );
};

export default NsAuthDropdown;
